@@ -27,8 +27,8 @@
 #include <kdebug.h>
 #endif
 
-#include "ratio.h"
-#include "ratiowidget.h"
+#include "Ratio.h"
+#include "RatioWidget.h"
 
 #include <qwidget.h>
 //Added by qt3to4:
@@ -46,13 +46,13 @@ class FractionPainter : public FractionBaseWidget
 
 public:
     /** constructor */
-    FractionPainter(QWidget * parent = 0);
+    explicit FractionPainter(QWidget * parent = 0);
 
     /** destructor */
     ~FractionPainter();
 
-    void paintFraction(const QString & str_operation, ratio & leftRatio, int leftMult,
-                       ratio & rightRatio, int rightMult);
+    void paintFraction(const QString & str_operation, Ratio & leftRatio, int leftMult,
+                       Ratio & rightRatio, int rightMult);
 protected:
     /** Function is called every time the screen need to be painted.
      **/
@@ -61,9 +61,9 @@ protected:
 
 private:
     QString str_operation;
-    ratio leftRatio;
+    Ratio leftRatio;
     int leftMult;
-    ratio rightRatio;
+    Ratio rightRatio;
     int rightMult;
 
 public slots:
